==> haskell-trifecta-1.6-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-trifecta.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: trifecta
version: 1.6
id: trifecta-1.6-BCs7ct3pSLm9uGi5TaT2pm
key: trifecta-1.6-BCs7ct3pSLm9uGi5TaT2pm
license: BSD3
copyright: Copyright (C) 2010-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/trifecta/
synopsis: A modern parser combinator library with convenient diagnostics
description:
    A modern parser combinator library with slicing and Clang-style colored diagnostics
category: Text, Parsing, Diagnostics, Pretty Printer, Logging
author: Edward A. Kmett
exposed: True
exposed-modules:
    Text.Trifecta Text.Trifecta.Combinators Text.Trifecta.Delta
    Text.Trifecta.Highlight Text.Trifecta.Parser
    Text.Trifecta.Rendering Text.Trifecta.Result Text.Trifecta.Rope
    Text.Trifecta.Util.Array Text.Trifecta.Util.IntervalMap
    Text.Trifecta.Util.It
hidden-modules: Text.Trifecta.Instances
                Text.Trifecta.Util.Combinators
abi: 6158bf4c9f10b3fbfe5b89fa719ef763
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/trifecta-1.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/trifecta-1.6
data-dir: /usr/share/arm-linux-ghc-8.0.1/trifecta-1.6
hs-libraries: HStrifecta-1.6-BCs7ct3pSLm9uGi5TaT2pm
depends:
    ansi-terminal-0.6.2.3-AKTYR0nthhUCHW4HMZvJFX
    ansi-wl-pprint-0.6.7.3-BxXaXM4de7bF6SGXMvMtbC array-0.5.1.1
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.1-BhhXJch8Gg8D1ETUvb8oFp
    blaze-markup-0.7.0.3-6iLNhqMnSkpL7LEeNEW58d bytestring-0.10.8.1
    charset-0.3.7.1-IfpzBcdrtrvG42nmA8DS1W
    comonad-5-Ho2qNHvdHPIFLXxnOyzkiN containers-0.5.7.1 deepseq-1.4.2.0
    fingertree-0.1.1.0-C6YFXKIQXOA6HvmvFT5gT9 ghc-prim-0.5.0.0
    hashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
    lens-4.14-2wnBKklir0DH86HB8pwADA mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    parsers-0.12.4-L9h9xLunM0a6e4WPoiTbJG
    profunctors-5.2-CvNMDKnJ912CHfnUU2mZbP
    reducers-3.12.1-Jhf7u9W7gT3F1AI8bn7ckm
    semigroups-0.18.2-1UW5ZEaP4Cw95AdO3Ej2Ky transformers-0.5.2.0
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
haddock-interfaces: /usr/share/doc/haskell-trifecta/html/trifecta.haddock
haddock-html: /usr/share/doc/haskell-trifecta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-trifecta-1.6.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-trifecta.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: trifecta
version: 1.6.1
id: trifecta-1.6.1-KSb5vTpKeYc1Zk87tE1VRY
key: trifecta-1.6.1-KSb5vTpKeYc1Zk87tE1VRY
license: BSD3
copyright: Copyright (C) 2010-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/trifecta/
synopsis: A modern parser combinator library with convenient diagnostics
description:
    A modern parser combinator library with slicing and Clang-style colored diagnostics
category: Text, Parsing, Diagnostics, Pretty Printer, Logging
author: Edward A. Kmett
exposed: True
exposed-modules:
    Text.Trifecta Text.Trifecta.Combinators Text.Trifecta.Delta
    Text.Trifecta.Highlight Text.Trifecta.Parser
    Text.Trifecta.Rendering Text.Trifecta.Result Text.Trifecta.Rope
    Text.Trifecta.Util.Array Text.Trifecta.Util.IntervalMap
    Text.Trifecta.Util.It
hidden-modules: Text.Trifecta.Instances
                Text.Trifecta.Util.Combinators
abi: 1d92ab0baa201d2e1c4e1d59ce5e16fe
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/trifecta-1.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/trifecta-1.6.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/trifecta-1.6.1
hs-libraries: HStrifecta-1.6.1-KSb5vTpKeYc1Zk87tE1VRY
depends:
    ansi-terminal-0.6.2.3-AKTYR0nthhUCHW4HMZvJFX
    ansi-wl-pprint-0.6.7.3-BxXaXM4de7bF6SGXMvMtbC array-0.5.1.1
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.2-2ceCZ3Fm7x67ZwaaR7uQ3C
    blaze-markup-0.7.1.0-BKRb0wHFpEyDJWTsyjQqnp bytestring-0.10.8.1
    charset-0.3.7.1-85hvTn97TA57rw44la5NP2
    comonad-5-1roHbXsedY6KUNYFgPJLp6 containers-0.5.7.1 deepseq-1.4.2.0
    fingertree-0.1.1.0-C6YFXKIQXOA6HvmvFT5gT9 ghc-prim-0.5.0.0
    hashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
    lens-4.15.1-DZbFGf4RlcKEQE2VkLJobh mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    parsers-0.12.4-8Rdt352V1Dr8vcnHZcwN0v
    profunctors-5.2-CUL7kUu4nBbDVNmgOaH64k
    reducers-3.12.1-76CqkbVLMgaBRGzGyW61zq
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz transformers-0.5.2.0
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
haddock-interfaces: /usr/share/doc/haskell-trifecta/html/trifecta.haddock
haddock-html: /usr/share/doc/haskell-trifecta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
